"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
var _exportNames = {
  cleanup: true,
  render: true,
  fireEvent: true
};
exports.cleanup = cleanup;
exports.render = render;
exports.fireEvent = fireEvent;

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));

var _testUtils = require("@vue/test-utils");

var _dom = require("@testing-library/dom");

Object.keys(_dom).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (Object.prototype.hasOwnProperty.call(_exportNames, key)) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function get() {
      return _dom[key];
    }
  });
});

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { (0, _defineProperty2.default)(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

var mountedWrappers = new Set();

function render(TestComponent) {
  var _ref = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

  var configurationCb = arguments.length > 2 ? arguments[2] : undefined;
  var _ref$store = _ref.store,
      store = _ref$store === void 0 ? null : _ref$store,
      _ref$routes = _ref.routes,
      routes = _ref$routes === void 0 ? null : _ref$routes,
      mountOptions = (0, _objectWithoutProperties2.default)(_ref, ["store", "routes"]);
  var localVue = (0, _testUtils.createLocalVue)();
  var vuexStore = null;
  var router = null;
  var additionalOptions = {};

  if (store) {
    var Vuex = require('vuex');

    localVue.use(Vuex);
    vuexStore = new Vuex.Store(store);
  }

  if (routes) {
    var VueRouter = require('vue-router');

    localVue.use(VueRouter);
    router = new VueRouter({
      routes: routes
    });
  }

  if (configurationCb && typeof configurationCb === 'function') {
    additionalOptions = configurationCb(localVue, vuexStore, router);
  }

  if (!mountOptions.propsData && !!mountOptions.props) {
    mountOptions.propsData = mountOptions.props;
    delete mountOptions.props;
  }

  var wrapper = (0, _testUtils.mount)(TestComponent, _objectSpread({
    localVue: localVue,
    router: router,
    store: vuexStore,
    attachToDocument: true,
    sync: false
  }, mountOptions, {}, additionalOptions));
  mountedWrappers.add(wrapper);

  if (wrapper.element.parentNode === document.body) {
    var div = document.createElement('div');
    wrapper.element.parentNode.insertBefore(div, wrapper.element);
    div.appendChild(wrapper.element);
  }

  return _objectSpread({
    container: wrapper.element.parentNode,
    baseElement: document.body,
    debug: function debug() {
      var el = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : wrapper.element;
      return (0, _dom.logDOM)(el);
    },
    unmount: function unmount() {
      return wrapper.destroy();
    },
    isUnmounted: function isUnmounted() {
      return wrapper.vm._isDestroyed;
    },
    html: function html() {
      return wrapper.html();
    },
    emitted: function emitted() {
      return wrapper.emitted();
    },
    updateProps: function updateProps(_) {
      wrapper.setProps(_);
      return (0, _dom.wait)();
    }
  }, (0, _dom.getQueriesForElement)(wrapper.element.parentNode));
}

function cleanup() {
  mountedWrappers.forEach(cleanupAtWrapper);
}

function cleanupAtWrapper(wrapper) {
  if (wrapper.element.parentNode && wrapper.element.parentNode.parentNode === document.body) {
    document.body.removeChild(wrapper.element.parentNode);
  }

  if (wrapper.isVueInstance()) {
    wrapper.destroy();
  }

  mountedWrappers.delete(wrapper);
} // Vue Testing Library's version of fireEvent will call DOM Testing Library's
// version of fireEvent plus wait for one tick of the event loop to allow Vue
// to asynchronously handle the event.
// More info: https://vuejs.org/v2/guide/reactivity.html#Async-Update-Queue


function fireEvent() {
  return _fireEvent.apply(this, arguments);
}

function _fireEvent() {
  _fireEvent = (0, _asyncToGenerator2.default)(
  /*#__PURE__*/
  _regenerator.default.mark(function _callee4() {
    var _args4 = arguments;
    return _regenerator.default.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            _dom.fireEvent.apply(void 0, _args4);

            _context4.next = 3;
            return (0, _dom.wait)();

          case 3:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  }));
  return _fireEvent.apply(this, arguments);
}

Object.keys(_dom.fireEvent).forEach(function (key) {
  fireEvent[key] =
  /*#__PURE__*/
  (0, _asyncToGenerator2.default)(
  /*#__PURE__*/
  _regenerator.default.mark(function _callee() {
    var _args = arguments;
    return _regenerator.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _dom.fireEvent[key].apply(_dom.fireEvent, _args);

            _context.next = 3;
            return (0, _dom.wait)();

          case 3:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  }));
});

fireEvent.touch =
/*#__PURE__*/
function () {
  var _ref3 = (0, _asyncToGenerator2.default)(
  /*#__PURE__*/
  _regenerator.default.mark(function _callee2(elem) {
    return _regenerator.default.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.next = 2;
            return fireEvent.focus(elem);

          case 2:
            _context2.next = 4;
            return fireEvent.blur(elem);

          case 4:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  }));

  return function (_x) {
    return _ref3.apply(this, arguments);
  };
}(); // Small utility to provide a better experience when working with v-model.
// Related upstream issue: https://github.com/vuejs/vue-test-utils/issues/345#issuecomment-380588199
// Examples: https://github.com/testing-library/vue-testing-library/blob/master/tests/__tests__/form.js


fireEvent.update =
/*#__PURE__*/
function () {
  var _ref4 = (0, _asyncToGenerator2.default)(
  /*#__PURE__*/
  _regenerator.default.mark(function _callee3(elem, value) {
    var tagName, type, parentSelectElement;
    return _regenerator.default.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            tagName = elem.tagName;
            type = elem.type;
            _context3.t0 = tagName;
            _context3.next = _context3.t0 === 'OPTION' ? 5 : _context3.t0 === 'INPUT' ? 8 : _context3.t0 === 'TEXTAREA' ? 15 : _context3.t0 === 'SELECT' ? 17 : 19;
            break;

          case 5:
            elem.selected = true;
            parentSelectElement = elem.parentElement.tagName === 'OPTGROUP' ? elem.parentElement.parentElement : elem.parentElement;
            return _context3.abrupt("return", fireEvent.change(parentSelectElement));

          case 8:
            if (!['checkbox', 'radio'].includes(type)) {
              _context3.next = 13;
              break;
            }

            elem.checked = true;
            return _context3.abrupt("return", fireEvent.change(elem));

          case 13:
            elem.value = value;
            return _context3.abrupt("return", fireEvent.input(elem));

          case 15:
            elem.value = value;
            return _context3.abrupt("return", fireEvent.input(elem));

          case 17:
            elem.value = value;
            return _context3.abrupt("return", fireEvent.change(elem));

          case 19:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  }));

  return function (_x2, _x3) {
    return _ref4.apply(this, arguments);
  };
}();